@@ -71,6 +71,7 @@ def convert(image, mode):
     image = image.convert(mode)
     return image, ImageDraw.Draw(image)
 
+
 def resize(image, W, H, resample=None):
     """
     Resize Image to given size
@@ -85,6 +86,7 @@ def resize(image, W, H, resample=None):
     image = image.resize((W, H), resample=resample)
     return image, ImageDraw.Draw(image)
 
+
 def resizeToFit(image, sizeToFit, smaller=False, resample=None):
     """
     Resize to given size mantaining aspect ratio
@@ -245,6 +247,7 @@ def drawText(x, y, draw, message, fontColor, font, anchor = 'lt'):
 
     return draw
 
+
 def drawTextInsideWidth(
     x1, x2, y, draw, message, font_name, font_size, font_color, justify=None
 ):
@@ -329,11 +332,16 @@ def drawMultiLine(
         return draw
 
 
-def fitSize(font_path, message, canvasW):
+def fitSize(fontPath, message, canvasW):
     """
+    return (int) optimal size of font inside a canvas
+    fontPath : str path to font
+    message : str or list of str
+    canvasW : int width of canvas
+
     return (int) optimal size of font inside a canvas
     """
-    font = fontDefiner(font_path, 100)
+    font = fontDefiner(fontPath, 100)
     if type(message) in [list, tuple]:
         w, _, h, _ = getMultipleSize(message, font)
     else:
@@ -341,22 +349,51 @@ def fitSize(font_path, message, canvasW):
     return 100 * canvasW // max(w, h)
 
 
+def fitFontInCanvas(fontPath, message, WH):
+    """
+    Fit the text inside the whole canvas
+    fontPath : str path to font
+    message : str or list/tuple of str
+    WH : list/tuple of sizes of canvas
+
+    return ImageFont
+    """
+
+    font = fontDefiner(fontPath, 100)
+
+    W, H = WH
+
+    if type(message) in [list, tuple]:
+        w, _, h, _ = getMultipleSize(message, font)
+    else:
+        w, h = getSize(message, font)
+
+    ratio = min(W / w, H / h)
+    size = int(100*ratio)
+
+    return fontDefiner(fontPath, size)
+
+
 def getSize(text_string, font):
     """
     Get size of single line text
     text_string: string
     font: font object
-    return text_width, text_height
     # https://stackoverflow.com/a/46220683/9263761
-    ascent, descent = font.getmetrics()
 
+    return text_width, text_height
+    """
+    """
+    ascent, descent = font.getmetrics()
     text_width = font.getmask(text_string).getbbox()[2]
     text_height = font.getmask(text_string).getbbox()[3] - ascent - descent
     """
     ascent, descent = font.getmetrics()
     text_width, text_height = font.getsize(text_string)
 
-    return (text_width, text_height-descent)
+    #return (text_width, text_height-descent)
+    return (text_width, text_height)
+
 
 
 def getMultipleSize(text_wrapped, font):
@@ -380,7 +417,7 @@ def getMultipleSize(text_wrapped, font):
         if height > max_height:
             max_height = height
 
-    spaces = int(max_height / 6)
+    spaces = int(max_height / 4)
     max_single_height = max_height
     max_height = max_height * len(text_wrapped) + spaces * (len(text_wrapped) - 1)
 
@@ -444,42 +481,26 @@ def mirror(image):
     return image
 
 
-def strokeImage(original, stroke, stroke_color="#FFFFFF"):
-    import numpy as np
-
-    blackThreshold = 1
-    contour = original.filter(ImageFilter.GaussianBlur(radius=stroke))
-    r, g, b, a = contour.split()  # supposing to have a RGBA PNG
-    contour = Image.merge("L", (a,))
-    contour = contour.point(lambda x: 0 if x < blackThreshold else 255)
-    contour = contour.convert("RGBA")
-
-    datas = np.array(contour)
-
-    r1, g1, b1, a1 = 0, 0, 0, 255  # Original value
-    r2, g2, b2, a2 = 255, 255, 255, 0  # Value that we want to replace it with
-
-    red, green, blue, alpha = (
-        datas[:, :, 0],
-        datas[:, :, 1],
-        datas[:, :, 2],
-        datas[:, :, 3],
-    )
-    mask = (red == r1) & (green == g1) & (blue == b1) & (alpha == a1)
-    datas[:, :, :4][mask] = [r2, g2, b2, a2]
+def strokeImage(original, stroke=1, stroke_color="#FFFFFF", smoother=1):
     """
-    datas = contour.getdata()
-    newData = []
-    for item in datas:
-        if item[0] == 0 and item[1] == 0 and item[2] == 0:
-            newData.append((0, 0, 0, 0))
-        else:
-            newData.append(item)
-    contour.putdata(newData)
+    Stroke the image with a color
+
+    original : Image
+    stroke : width of stroke, int
+    stroke_color : color of the stroke, str of hex color
+    smoother : increment to have a smoother contour (more time needed), int
+
+    return Image
     """
 
-    contour = Image.fromarray(datas)
-    contour = fillWithColor(contour, stroke_color)
+    if smoother:
+        stroke /= smoother
+    original = original.convert("RGBA")
+    contour = fillWithColor(original, stroke_color)
+    for i in range(smoother):
+        contour = contour.filter(ImageFilter.GaussianBlur(radius=stroke))
+
+    contour = fillOpaque(contour)
     contour = blurImage(contour, 1)
     original = pasteItem(contour, original, 0, 0)
 
@@ -499,6 +520,10 @@ def blurImage(image, radius):
 def roundCorners(im, rad):
     """
     Rounds the corners of an image to given radius
+    im: Image object
+    rad: radius of edges
+
+    return Image
     """
     mask = Image.new("L", im.size)
     if rad > min(*im.size) // 2:
@@ -524,10 +549,12 @@ def roundCorners(im, rad):
 def roundCornersAngles(im, rad, angles):
     """
     Rounds only specific corners of the image
-    im: image object
+    im: Image object
     rad: radius
     angles: list of numbers from 1 to 4, clockwise, starting from the upper left
     just pass the corners you want to be rounded
+
+    return Image
     """
     circle = Image.new("L", (rad * 2, rad * 2), 0)
     draw = ImageDraw.Draw(circle)
@@ -552,8 +579,10 @@ def roundCornersAngles(im, rad, angles):
 def fillWithColor(image, color):
     """
     Fill the entire canvas or png with one color
-    img: image object
+    img: Image object
     color: color to use
+
+    return Image
     """
     image = image.convert("RGBA")
     alpha = image.getchannel("A")
@@ -746,7 +775,6 @@ def pol2Cart(r, degrees, centerW=0, centerH=0):
 
     return x, y
 
-
 # Conversion between color spaces
 def hexToRgb(hex):
     """
